# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/community/attribute.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n eolymp/community/attribute.proto\x12\x10\x65olymp.community\"\xb3\x06\n\tAttribute\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05label\x18\x02 \x01(\t\x12\x0c\n\x04help\x18\x03 \x01(\t\x12<\n\x0b\x64\x65scription\x18\n \x03(\x0b\x32\'.eolymp.community.Attribute.Description\x12.\n\x04type\x18\x14 \x01(\x0e\x32 .eolymp.community.Attribute.Type\x12\r\n\x05index\x18\x15 \x01(\r\x12\x10\n\x08required\x18\x1f \x01(\x08\x12\x10\n\x08readonly\x18! \x01(\x08\x12\x0e\n\x06hidden\x18  \x01(\x08\x12:\n\nvisibility\x18\" \x01(\x0e\x32&.eolymp.community.Attribute.Visibility\x12\x0e\n\x06regexp\x18\x64 \x01(\t\x12\x0b\n\x03min\x18\x65 \x01(\x05\x12\x0b\n\x03max\x18\x66 \x01(\x05\x12\x0f\n\x07\x63hoices\x18g \x03(\t\x12\x0f\n\x07\x63ountry\x18h \x01(\t\x12\x13\n\x0b\x63onstraints\x18i \x03(\t\x1aK\n\x0b\x44\x65scription\x12\x0e\n\x06locale\x18\x02 \x01(\t\x12\r\n\x05label\x18\x03 \x01(\t\x12\x0c\n\x04help\x18\x04 \x01(\t\x12\x0f\n\x07\x63hoices\x18\x05 \x03(\t\x1a\x85\x01\n\x05Value\x12\x15\n\rattribute_key\x18\x01 \x01(\t\x12\x38\n\x0e\x61ttribute_type\x18\x02 \x01(\x0e\x32 .eolymp.community.Attribute.Type\x12\x10\n\x06string\x18\n \x01(\tH\x00\x12\x10\n\x06number\x18\x0b \x01(\x05H\x00\x42\x07\n\x05value\"\xa3\x01\n\x04Type\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06STRING\x10\x01\x12\x08\n\x04TEXT\x10\x02\x12\n\n\x06NUMBER\x10\x03\x12\n\n\x06\x43HOICE\x10\x04\x12\x08\n\x04\x44\x41TE\x10\x05\x12\t\n\x05\x45MAIL\x10\x06\x12\x0c\n\x08\x43HECKBOX\x10\x07\x12\x0b\n\x07\x43OUNTRY\x10\x08\x12\n\n\x06REGION\x10\t\x12\x0f\n\x0bINSTITUTION\x10\n\x12\t\n\x05IMAGE\x10\x0b\x12\x08\n\x04\x46ILE\x10\x0c\"3\n\nVisibility\x12\x0c\n\x08INTERNAL\x10\x00\x12\x0b\n\x07PRIVATE\x10\x01\x12\n\n\x06PUBLIC\x10\x02\x42\x35Z3github.com/eolymp/go-sdk/eolymp/community;communityb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.community.attribute_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/community;community'
  _ATTRIBUTE._serialized_start=55
  _ATTRIBUTE._serialized_end=874
  _ATTRIBUTE_DESCRIPTION._serialized_start=444
  _ATTRIBUTE_DESCRIPTION._serialized_end=519
  _ATTRIBUTE_VALUE._serialized_start=522
  _ATTRIBUTE_VALUE._serialized_end=655
  _ATTRIBUTE_TYPE._serialized_start=658
  _ATTRIBUTE_TYPE._serialized_end=821
  _ATTRIBUTE_VISIBILITY._serialized_start=823
  _ATTRIBUTE_VISIBILITY._serialized_end=874
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/atlas/script_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.atlas import script_pb2 as eolymp_dot_atlas_dot_script__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!eolymp/atlas/script_service.proto\x12\x0c\x65olymp.atlas\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x19\x65olymp/atlas/script.proto\x1a eolymp/wellknown/direction.proto\x1a!eolymp/wellknown/expression.proto\"9\n\x11\x43reateScriptInput\x12$\n\x06script\x18\x01 \x01(\x0b\x32\x14.eolymp.atlas.Script\"\'\n\x12\x43reateScriptOutput\x12\x11\n\tscript_id\x18\x01 \x01(\t\"\xd2\x01\n\x11UpdateScriptInput\x12\x34\n\x05patch\x18\x01 \x03(\x0e\x32%.eolymp.atlas.UpdateScriptInput.Patch\x12\x11\n\tscript_id\x18\x02 \x01(\t\x12$\n\x06script\x18\x03 \x01(\x0b\x32\x14.eolymp.atlas.Script\"N\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\x08\n\x04NAME\x10\x01\x12\n\n\x06SECRET\x10\x02\x12\x0b\n\x07RUNTIME\x10\x03\x12\x0e\n\nSOURCE_URL\x10\x04\x12\t\n\x05\x46ILES\x10\x05\"\x14\n\x12UpdateScriptOutput\"&\n\x11\x44\x65leteScriptInput\x12\x11\n\tscript_id\x18\x01 \x01(\t\"\x14\n\x12\x44\x65leteScriptOutput\"9\n\x13\x44\x65scribeScriptInput\x12\x11\n\tscript_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x64 \x01(\r\"<\n\x14\x44\x65scribeScriptOutput\x12$\n\x06script\x18\x01 \x01(\x0b\x32\x14.eolymp.atlas.Script\"\x9d\x03\n\x10ListScriptsInput\x12\x0f\n\x07version\x18\x64 \x01(\r\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x36\n\x07\x66ilters\x18( \x01(\x0b\x32%.eolymp.atlas.ListScriptsInput.Filter\x12\x35\n\x04sort\x18\x32 \x01(\x0e\x32\'.eolymp.atlas.ListScriptsInput.Sortable\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x1a\xa8\x01\n\x06\x46ilter\x12\r\n\x05query\x18\x01 \x01(\t\x12*\n\x02id\x18\n \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x04name\x18\x0b \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12\x31\n\x07runtime\x18\x0c \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"\x14\n\x08Sortable\x12\x08\n\x04NAME\x10\x00\"G\n\x11ListScriptsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12#\n\x05items\x18\x02 \x03(\x0b\x32\x14.eolymp.atlas.Script2\x84\x06\n\rScriptService\x12\x8d\x01\n\x0c\x43reateScript\x12\x1f.eolymp.atlas.CreateScriptInput\x1a .eolymp.atlas.CreateScriptOutput\":\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\n\x1a\x08/scripts\x12\x99\x01\n\x0cUpdateScript\x12\x1f.eolymp.atlas.UpdateScriptInput\x1a .eolymp.atlas.UpdateScriptOutput\"F\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x16\x1a\x14/scripts/{script_id}\x12\x99\x01\n\x0c\x44\x65leteScript\x12\x1f.eolymp.atlas.DeleteScriptInput\x1a .eolymp.atlas.DeleteScriptOutput\"F\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x16*\x14/scripts/{script_id}\x12\x9e\x01\n\x0e\x44\x65scribeScript\x12!.eolymp.atlas.DescribeScriptInput\x1a\".eolymp.atlas.DescribeScriptOutput\"E\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x16\x12\x14/scripts/{script_id}\x12\x89\x01\n\x0bListScripts\x12\x1e.eolymp.atlas.ListScriptsInput\x1a\x1f.eolymp.atlas.ListScriptsOutput\"9\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\n\x12\x08/scriptsB-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.script_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _SCRIPTSERVICE.methods_by_name['CreateScript']._options = None
  _SCRIPTSERVICE.methods_by_name['CreateScript']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\n\032\010/scripts'
  _SCRIPTSERVICE.methods_by_name['UpdateScript']._options = None
  _SCRIPTSERVICE.methods_by_name['UpdateScript']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\026\032\024/scripts/{script_id}'
  _SCRIPTSERVICE.methods_by_name['DeleteScript']._options = None
  _SCRIPTSERVICE.methods_by_name['DeleteScript']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\026*\024/scripts/{script_id}'
  _SCRIPTSERVICE.methods_by_name['DescribeScript']._options = None
  _SCRIPTSERVICE.methods_by_name['DescribeScript']._serialized_options = b'\202\343\n\026\212\343\n\022atlas:problem:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\026\022\024/scripts/{script_id}'
  _SCRIPTSERVICE.methods_by_name['ListScripts']._options = None
  _SCRIPTSERVICE.methods_by_name['ListScripts']._serialized_options = b'\202\343\n\026\212\343\n\022atlas:problem:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\n\022\010/scripts'
  _CREATESCRIPTINPUT._serialized_start=246
  _CREATESCRIPTINPUT._serialized_end=303
  _CREATESCRIPTOUTPUT._serialized_start=305
  _CREATESCRIPTOUTPUT._serialized_end=344
  _UPDATESCRIPTINPUT._serialized_start=347
  _UPDATESCRIPTINPUT._serialized_end=557
  _UPDATESCRIPTINPUT_PATCH._serialized_start=479
  _UPDATESCRIPTINPUT_PATCH._serialized_end=557
  _UPDATESCRIPTOUTPUT._serialized_start=559
  _UPDATESCRIPTOUTPUT._serialized_end=579
  _DELETESCRIPTINPUT._serialized_start=581
  _DELETESCRIPTINPUT._serialized_end=619
  _DELETESCRIPTOUTPUT._serialized_start=621
  _DELETESCRIPTOUTPUT._serialized_end=641
  _DESCRIBESCRIPTINPUT._serialized_start=643
  _DESCRIBESCRIPTINPUT._serialized_end=700
  _DESCRIBESCRIPTOUTPUT._serialized_start=702
  _DESCRIBESCRIPTOUTPUT._serialized_end=762
  _LISTSCRIPTSINPUT._serialized_start=765
  _LISTSCRIPTSINPUT._serialized_end=1178
  _LISTSCRIPTSINPUT_FILTER._serialized_start=988
  _LISTSCRIPTSINPUT_FILTER._serialized_end=1156
  _LISTSCRIPTSINPUT_SORTABLE._serialized_start=1158
  _LISTSCRIPTSINPUT_SORTABLE._serialized_end=1178
  _LISTSCRIPTSOUTPUT._serialized_start=1180
  _LISTSCRIPTSOUTPUT._serialized_end=1251
  _SCRIPTSERVICE._serialized_start=1254
  _SCRIPTSERVICE._serialized_end=2026
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.newsletter import recipient_pb2 as _recipient_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateRecipientInput(_message.Message):
    __slots__ = ["recipient"]
    RECIPIENT_FIELD_NUMBER: _ClassVar[int]
    recipient: _recipient_pb2.Recipient
    def __init__(self, recipient: _Optional[_Union[_recipient_pb2.Recipient, _Mapping]] = ...) -> None: ...

class CreateRecipientOutput(_message.Message):
    __slots__ = ["recipient_id"]
    RECIPIENT_ID_FIELD_NUMBER: _ClassVar[int]
    recipient_id: str
    def __init__(self, recipient_id: _Optional[str] = ...) -> None: ...

class DescribeRecipientInput(_message.Message):
    __slots__ = ["recipient_id"]
    RECIPIENT_ID_FIELD_NUMBER: _ClassVar[int]
    recipient_id: str
    def __init__(self, recipient_id: _Optional[str] = ...) -> None: ...

class DescribeRecipientOutput(_message.Message):
    __slots__ = ["recipient"]
    RECIPIENT_FIELD_NUMBER: _ClassVar[int]
    recipient: _recipient_pb2.Recipient
    def __init__(self, recipient: _Optional[_Union[_recipient_pb2.Recipient, _Mapping]] = ...) -> None: ...

class ImportRecipientsInput(_message.Message):
    __slots__ = ["group_id"]
    GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    group_id: str
    def __init__(self, group_id: _Optional[str] = ...) -> None: ...

class ImportRecipientsOutput(_message.Message):
    __slots__ = ["imported_total"]
    IMPORTED_TOTAL_FIELD_NUMBER: _ClassVar[int]
    imported_total: str
    def __init__(self, imported_total: _Optional[str] = ...) -> None: ...

class ListRecipientsInput(_message.Message):
    __slots__ = ["offset", "size"]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    offset: int
    size: int
    def __init__(self, offset: _Optional[int] = ..., size: _Optional[int] = ...) -> None: ...

class ListRecipientsOutput(_message.Message):
    __slots__ = ["items", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_recipient_pb2.Recipient]
    total: int
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_recipient_pb2.Recipient, _Mapping]]] = ...) -> None: ...

class RemoveRecipientInput(_message.Message):
    __slots__ = ["recipient_id"]
    RECIPIENT_ID_FIELD_NUMBER: _ClassVar[int]
    recipient_id: str
    def __init__(self, recipient_id: _Optional[str] = ...) -> None: ...

class RemoveRecipientOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Institution(_message.Message):
    __slots__ = ["acronym", "address", "country_id", "governance", "id", "level", "links", "local_acronym", "local_name", "logo_url", "name", "region_id", "type"]
    class Governance(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Level(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Type(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class LinksEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    ACADEMY: Institution.Type
    ACRONYM_FIELD_NUMBER: _ClassVar[int]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    CHARTER: Institution.Governance
    COLLEGE: Institution.Type
    COUNTRY_ID_FIELD_NUMBER: _ClassVar[int]
    GOVERNANCE_FIELD_NUMBER: _ClassVar[int]
    GYMNASIUM: Institution.Type
    ID_FIELD_NUMBER: _ClassVar[int]
    INSTITUTE: Institution.Type
    KINDERGARTEN: Institution.Type
    LEVEL_FIELD_NUMBER: _ClassVar[int]
    LINKS_FIELD_NUMBER: _ClassVar[int]
    LOCAL_ACRONYM_FIELD_NUMBER: _ClassVar[int]
    LOCAL_NAME_FIELD_NUMBER: _ClassVar[int]
    LOGO_URL_FIELD_NUMBER: _ClassVar[int]
    LYCEUM: Institution.Type
    NAME_FIELD_NUMBER: _ClassVar[int]
    PRESCHOOL: Institution.Level
    PRIMARY: Institution.Level
    PRIVATE: Institution.Governance
    PUBLIC: Institution.Governance
    REGION_ID_FIELD_NUMBER: _ClassVar[int]
    SCHOOL: Institution.Type
    SECONDARY: Institution.Level
    TERTIARY: Institution.Level
    TYPE_FIELD_NUMBER: _ClassVar[int]
    UNIVERSITY: Institution.Type
    UNKNOWN_GOVERNANCE: Institution.Governance
    UNKNOWN_LEVEL: Institution.Level
    UNKNOWN_TYPE: Institution.Type
    acronym: str
    address: str
    country_id: str
    governance: Institution.Governance
    id: str
    level: Institution.Level
    links: _containers.ScalarMap[str, str]
    local_acronym: str
    local_name: str
    logo_url: str
    name: str
    region_id: str
    type: Institution.Type
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., acronym: _Optional[str] = ..., local_name: _Optional[str] = ..., local_acronym: _Optional[str] = ..., logo_url: _Optional[str] = ..., governance: _Optional[_Union[Institution.Governance, str]] = ..., level: _Optional[_Union[Institution.Level, str]] = ..., type: _Optional[_Union[Institution.Type, str]] = ..., country_id: _Optional[str] = ..., region_id: _Optional[str] = ..., address: _Optional[str] = ..., links: _Optional[_Mapping[str, str]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/course/module.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.ecm import content_pb2 as eolymp_dot_ecm_dot_content__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x65olymp/course/module.proto\x12\reolymp.course\x1a\x18\x65olymp/ecm/content.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa6\x06\n\x06Module\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\r\n\x05\x64raft\x18\x03 \x01(\x08\x12\r\n\x05\x65xtra\x18\x07 \x01(\x08\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x11\n\timage_url\x18\x05 \x01(\t\x12\r\n\x05index\x18\x06 \x01(\r\x12(\n\x0b\x64\x65scription\x18\n \x01(\x0b\x32\x13.eolymp.ecm.Content\x12\x10\n\x08progress\x18\x14 \x01(\x02\x12\r\n\x05grade\x18\x15 \x01(\r\x12\x34\n\nassignment\x18\x1e \x01(\x0b\x32 .eolymp.course.Module.Assignment\x1a\xbf\x03\n\nAssignment\x12\x37\n\x06status\x18\n \x01(\x0e\x32\'.eolymp.course.Module.Assignment.Status\x12/\n\x0bstart_after\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x33\n\x0f\x63omplete_before\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08\x64uration\x18\r \x01(\r\x12/\n\x0b\x61ssigned_at\x18\x14 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nstarted_at\x18\x19 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0c\x63ompleted_at\x18\x1a \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"m\n\x06Status\x12\x12\n\x0eUNKNOWN_STATUS\x10\x00\x12\x0e\n\nUNASSIGNED\x10\x01\x12\r\n\tSCHEDULED\x10\x03\x12\t\n\x05READY\x10\x04\x12\n\n\x06\x41\x43TIVE\x10\x05\x12\x0c\n\x08\x43OMPLETE\x10\x06\x12\x0b\n\x07UPSOLVE\x10\x07\"r\n\x05\x45xtra\x12\x11\n\rUNKNOWN_EXTRA\x10\x00\x12\x15\n\x11\x44\x45SCRIPTION_VALUE\x10\x01\x12\x16\n\x12\x44\x45SCRIPTION_RENDER\x10\x02\x12\x0e\n\nASSIGNMENT\x10\x03\x12\x0c\n\x08PROGRESS\x10\x04\x12\t\n\x05GRADE\x10\x05\x42/Z-github.com/eolymp/go-sdk/eolymp/course;courseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.course.module_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/course;course'
  _MODULE._serialized_start=105
  _MODULE._serialized_end=911
  _MODULE_ASSIGNMENT._serialized_start=348
  _MODULE_ASSIGNMENT._serialized_end=795
  _MODULE_ASSIGNMENT_STATUS._serialized_start=686
  _MODULE_ASSIGNMENT_STATUS._serialized_end=795
  _MODULE_EXTRA._serialized_start=797
  _MODULE_EXTRA._serialized_end=911
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/executor/status.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.executor import stats_pb2 as eolymp_dot_executor_dot_stats__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x65olymp/executor/status.proto\x12\x0f\x65olymp.executor\x1a\x1b\x65olymp/executor/stats.proto\"\xde\t\n\x06Status\x12\x11\n\treference\x18\x01 \x01(\t\x12\x0e\n\x06origin\x18\x02 \x01(\t\x12*\n\x04type\x18\n \x01(\x0e\x32\x1c.eolymp.executor.Status.Type\x12\r\n\x05\x65rror\x18\x14 \x01(\t\x12\x0f\n\x07\x66\x61ilure\x18\x1e \x01(\t\x12)\n\x04runs\x18( \x03(\x0b\x32\x1b.eolymp.executor.Status.Run\x12\x11\n\tsignature\x18\x32 \x01(\t\x12\x0f\n\x07version\x18\x64 \x01(\r\x12\r\n\x05\x61gent\x18n \x01(\t\x1a\xd0\x07\n\x03Run\x12\x11\n\treference\x18\x01 \x01(\t\x12\x32\n\x06status\x18\x02 \x01(\x0e\x32\".eolymp.executor.Status.Run.Status\x12\r\n\x05score\x18P \x01(\x02\x12\x0c\n\x04\x63ost\x18Q \x01(\x02\x12\x17\n\x0fwall_time_usage\x18\x33 \x01(\r\x12\x17\n\x0fwall_time_limit\x18= \x01(\r\x12\x16\n\x0e\x63pu_time_usage\x18\x34 \x01(\r\x12\x16\n\x0e\x63pu_time_limit\x18> \x01(\r\x12\x14\n\x0cmemory_usage\x18\x35 \x01(\x04\x12\x14\n\x0cmemory_limit\x18? \x01(\x04\x12\x11\n\texit_code\x18\x46 \x01(\r\x12\x0e\n\x06signal\x18G \x01(\r\x12\x11\n\tinput_url\x18\n \x01(\t\x12\x12\n\noutput_url\x18\x0b \x01(\t\x12\x12\n\nanswer_url\x18\x0c \x01(\t\x12\x12\n\nstderr_url\x18\x15 \x01(\t\x12+\n\x0b\x64\x65\x62ug_stats\x18Z \x01(\x0b\x32\x16.eolymp.executor.Stats\x12\x17\n\x0f\x63hecker_log_url\x18\x1f \x01(\t\x12\x1f\n\x17\x63hecker_wall_time_usage\x18  \x01(\r\x12\x1c\n\x14\x63hecker_memory_usage\x18! \x01(\x04\x12\x19\n\x11\x63hecker_exit_code\x18\" \x01(\r\x12-\n\rchecker_stats\x18# \x01(\x0b\x32\x16.eolymp.executor.Stats\x12\x1a\n\x12interactor_log_url\x18) \x01(\t\x12\"\n\x1ainteractor_wall_time_usage\x18* \x01(\r\x12\x1f\n\x17interactor_memory_usage\x18+ \x01(\x04\x12\x1c\n\x14interactor_exit_code\x18, \x01(\r\x12\x30\n\x10interactor_stats\x18- \x01(\x0b\x32\x16.eolymp.executor.Stats\"\xe4\x01\n\x06Status\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\r\n\tEXECUTING\x10\x02\x12\x0b\n\x07TIMEOUT\x10\x03\x12\x11\n\rCPU_EXHAUSTED\x10\x04\x12\x13\n\x0fMEMORY_OVERFLOW\x10\x05\x12\x11\n\rRUNTIME_ERROR\x10\x06\x12\x0c\n\x08\x45XECUTED\x10\x07\x12\x0c\n\x08\x41\x43\x43\x45PTED\x10\x08\x12\x10\n\x0cWRONG_ANSWER\x10\t\x12\x18\n\x14VERIFICATION_FAILURE\x10\n\x12\x0b\n\x07SKIPPED\x10\x0b\x12\x17\n\x13INTERACTION_FAILURE\x10\x0c\"4\n\x04Type\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06UPDATE\x10\x01\x12\t\n\x05\x45RROR\x10\x02\x12\x0b\n\x07\x46\x41ILURE\x10\x03\x42\x33Z1github.com/eolymp/go-sdk/eolymp/executor;executorb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.executor.status_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/executor;executor'
  _STATUS._serialized_start=79
  _STATUS._serialized_end=1325
  _STATUS_RUN._serialized_start=295
  _STATUS_RUN._serialized_end=1271
  _STATUS_RUN_STATUS._serialized_start=1043
  _STATUS_RUN_STATUS._serialized_end=1271
  _STATUS_TYPE._serialized_start=1273
  _STATUS_TYPE._serialized_end=1325
# @@protoc_insertion_point(module_scope)
